@@ -1,6 +1,22 @@
-// (c) 2000 Peter Putzer
+/*
+   Copyright 2000 Peter Putzer <putzer@kde.org>
 
-#include <qdatastream.h>
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
+#include <QDataStream>
 #include <kdatastream.h>
 
 #include "Data.h"
@@ -12,7 +28,7 @@ KSVData::KSVData ()
 }
 
 KSVData::KSVData (const QString& file, const QString& path,
-                  const QString& label, Q_INT8 nr)
+                  const QString& label, qint8 nr)
   : mPath (path),
     mLabel (label), mFilename (file)
 {
@@ -129,7 +145,7 @@ void KSVData::setRunlevel (const QString& s)
   mRunlevel = s;
 }
 
-void KSVData::setNumber (Q_INT8 nr)
+void KSVData::setNumber (qint8 nr)
 {
   if (!mNrChanged && mNr != nr)
     {
