@@ -18,36 +18,39 @@
  **                                     **
  *****************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <qprogressdialog.h>
-#include <qkeycode.h>
+#include <kxmlguifactory.h>
+#include <q3progressdialog.h>
+#include <qnamespace.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
-#include <qaccel.h>
+#include <q3groupbox.h>
+#include <q3accel.h>
 #include <qscrollbar.h>
-#include <qtextedit.h>
-#include <qcstring.h>
+#include <q3textedit.h>
+#include <q3cstring.h>
 #include <qclipboard.h>
-#include <qheader.h>
-#include <qlabel.h>
-#include <qstylesheet.h>
-#include <qwhatsthis.h>
-#include <qlayout.h>
-#include <qvbox.h>
-#include <qvaluelist.h>
+#include <q3header.h>
+#include <QLabel>
+#include <q3stylesheet.h>
+
+#include <QLayout>
+#include <q3vbox.h>
+#include <q3valuelist.h>
 #include <qsplitter.h>
-#include <qmap.h>
+#include <QMap>
+//Added by qt3to4:
+#include <QMoveEvent>
+#include <Q3PtrList>
+#include <Q3Frame>
+#include <QHBoxLayout>
+#include <QShowEvent>
+#include <QResizeEvent>
 
-#include <kapplication.h>
 #include <kdebug.h>
 #include <kiconloader.h>
-#include <kprocess.h>
+#include <k3process.h>
 #include <kstandarddirs.h>
 #include <kcursor.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kglobalsettings.h>
@@ -56,7 +59,6 @@
 #include <kdirwatch.h>
 #include <kcompletion.h>
 #include <krun.h>
-#include <kopenwith.h>
 #include <kmimemagic.h>
 
 #include "kbusymanager.h"
@@ -72,28 +74,28 @@
 #include "ActionList.h"
 #include "TopWidget.h"
 
-KSVContent::KSVContent (KPopupMenu* openWithMenu, KSVTopLevel* parent, const char* name)
-  : QSplitter (QSplitter::Vertical, parent, name),
+KSVContent::KSVContent (KMenu* openWithMenu, KSVTopLevel* parent, const char* name)
+  : QSplitter (Qt::Vertical, parent, name),
     startRL (new KSVDragList*[ksv::runlevelNumber]),
     stopRL (new KSVDragList*[ksv::runlevelNumber]),
     conf(KSVConfig::self()),
 	mScriptBox (0L),
-    mRunlevels (new QVBox*[ksv::runlevelNumber]),
+    mRunlevels (new Q3VBox*[ksv::runlevelNumber]),
 	mOrigin (0L),
-    mOpenWithMenu (openWithMenu), m_buffer( QCString() )
+    mOpenWithMenu (openWithMenu), m_buffer( Q3CString() )
 {
   setOpaqueResize( KGlobalSettings::opaqueResize() );
 
   KXMLGUIFactory* factory = parent->factory();
-  mItemMenu = static_cast<KPopupMenu*> (factory->container ("item_menu", parent));
-  mItemMenu->insertTitle (i18n ("Runlevel Menu"), -1, 0);
-  mContextMenu = static_cast<KPopupMenu*> (factory->container ("list_menu", parent));
-  mContextMenu->insertTitle (i18n ("Runlevel Menu"), -1, 0);
-  mScriptMenu = static_cast<KPopupMenu*> (factory->container ("script_menu", parent));
-  mScriptMenu->insertTitle (i18n ("Services Menu"), -1, 0);
+  mItemMenu = static_cast<KMenu*> (factory->container ("item_menu", parent));
+  mItemMenu->addTitle (i18n ("Runlevel Menu"), -1, 0);
+  mContextMenu = static_cast<KMenu*> (factory->container ("list_menu", parent));
+  mContextMenu->addTitle (i18n ("Runlevel Menu"), -1, 0);
+  mScriptMenu = static_cast<KMenu*> (factory->container ("script_menu", parent));
+  mScriptMenu->addTitle (i18n ("Services Menu"), -1, 0);
 
   mScroller = new KScroller (this);
-  mContent = new QFrame(mScroller, "KSysV Real Content");
+  mContent = new Q3Frame(mScroller, "KSysV Real Content");
 
   mScroller->setContent (mContent);
 
@@ -185,16 +187,16 @@ void KSVContent::updateRunlevelsAfterChange ()
 void KSVContent::initLList()
 {
   QHBoxLayout *lay = new QHBoxLayout( mContent, KDialog::marginHint(), KDialog::spacingHint() );
-  mScriptBox = new QVBox (mContent);
+  mScriptBox = new Q3VBox (mContent);
   lay->addWidget(mScriptBox);
   mScriptBox->setSpacing (KDialog::spacingHint());
 
-  QVBox* scriptLabelBox = new QVBox (mScriptBox);
+  Q3VBox* scriptLabelBox = new Q3VBox (mScriptBox);
   QLabel* servL = new QLabel (i18n("&Available\n" \
                                    "Services"), scriptLabelBox);
 
   // provide quickhelp
-  QWhatsThis::add (scriptLabelBox,
+  scriptLabelBox->setWhatsThis(
 				   i18n("<p>These are the <img src=\"small|exec\"/> <strong>services</strong> available on your computer. " \
 						"To start a service, drag it onto the <em>Start</em> " \
 						"section of a runlevel.</p>" \
@@ -207,26 +209,26 @@ void KSVContent::initLList()
 
   scripts = new KServiceDragList (scriptLabelBox, "Scripts");
   scripts->setAcceptDrops (false);
-  scripts->setColumnWidthMode (KSVItem::SortNumber, QListView::Manual);
+  scripts->setColumnWidthMode (KSVItem::SortNumber, Q3ListView::Manual);
   scripts->setColumnWidth(KSVItem::SortNumber,0);
   scripts->setSorting (KSVItem::ServiceName);
   scripts->header()->setResizeEnabled (false, 0);
 
-  scripts->setDefaultIcon (SmallIcon("exec"));
+  scripts->setDefaultIcon (SmallIcon("system-run"));
   mOrigin = scripts;
 
   // setBuddy
   servL->setBuddy(scripts);
 
   // doubleclick && return
-  connect (scripts, SIGNAL(executed(QListViewItem*)),
-		   this, SLOT(slotScriptProperties(QListViewItem*)));
-  connect (scripts, SIGNAL (returnPressed (QListViewItem*)),
-		   this, SLOT (slotScriptProperties (QListViewItem*)));
+  connect (scripts, SIGNAL(executed(Q3ListViewItem*)),
+		   this, SLOT(slotScriptProperties(Q3ListViewItem*)));
+  connect (scripts, SIGNAL (returnPressed (Q3ListViewItem*)),
+		   this, SLOT (slotScriptProperties (Q3ListViewItem*)));
 
   // context menus
-  connect (scripts, SIGNAL (contextMenu (KListView*, QListViewItem*, const QPoint&)),
- 		   this, SLOT (popupServicesMenu (KListView*, QListViewItem*, const QPoint&)));
+  connect (scripts, SIGNAL (contextMenu (K3ListView*, Q3ListViewItem*, const QPoint&)),
+ 		   this, SLOT (popupServicesMenu (K3ListView*, Q3ListViewItem*, const QPoint&)));
 
   // for cut & copy
   connect (scripts, SIGNAL (newOrigin ()),
@@ -238,7 +240,7 @@ void KSVContent::initLList()
 
   trash = new KSVTrash(mScriptBox, "Trash");
   connect (trash, SIGNAL (undoAction (KSVAction*)), this, SLOT (fwdUndoAction (KSVAction*)));
-  QWhatsThis::add (trash,
+  trash->setWhatsThis(
 				   i18n ("<p>You can drag services from a runlevel onto " \
                          "the <img src=\"small|trash\"/> <strong>trashcan</strong> to " \
 						 "delete them from that runlevel.</p><p>The <strong>Undo command</strong> "\
@@ -246,23 +248,23 @@ void KSVContent::initLList()
 
   for(int i = 0; i < ksv::runlevelNumber; ++i)
     {
-      mRunlevels[i] = new QVBox (mContent);
+      mRunlevels[i] = new Q3VBox (mContent);
       lay->addWidget(mRunlevels[i]);
       mRunlevels[i]->setSpacing (KDialog::spacingHint());
 
       // create QString for label
-      QString _label (i18n("Runlevel &%1").arg(i));
+      QString _label (i18n("Runlevel &%1", i));
       // and for the name
-      QString _name (i18n("Runlevel %1").arg(i));
+      QString _name (i18n("Runlevel %1", i));
 
-      QVBox* startBox = new QVBox (mRunlevels[i]);
-      QWhatsThis::add (startBox,
+      Q3VBox* startBox = new Q3VBox (mRunlevels[i]);
+      startBox->setWhatsThis(
 					   i18n("<p>These are the services <strong>started</strong> in runlevel %1.</p>" \
 							"<p>The number shown on the left of the <img src=\"user|ksysv_start\"/> icon " \
 							"determines the order in which the services are started. " \
 							"You can arrange them via drag and drop, as long as a suitable " \
 							"<em>sorting number</em> can be generated.</p><p>If that's not possible, you have " \
-							"to change the number manually via the <strong>Properties dialog box</strong>.</p>").arg(i));
+							"to change the number manually via the <strong>Properties dialog box</strong>.</p>", i));
 
       QLabel* rlL = new QLabel(_label, startBox);
       new QLabel(i18n("Start"), startBox);
@@ -272,15 +274,15 @@ void KSVContent::initLList()
       startRL[i] = new KSVDragList(startBox, (_name + " START").latin1());
       startRL[i]->setDefaultIcon(SmallIcon("ksysv_start"));
 
-      QVBox* stopBox = new QVBox (mRunlevels[i]);
+      Q3VBox* stopBox = new Q3VBox (mRunlevels[i]);
       new QLabel(i18n("Stop"), stopBox);
-      QWhatsThis::add (stopBox,
+      stopBox->setWhatsThis(
 					   i18n("<p>These are the services <strong>stopped</strong> in runlevel %1.</p>" \
 							"<p>The number shown on the left of the <img src=\"user|ksysv_stop\"/> icon " \
 							"determines the order in which the services are stopped. " \
 							"You can arrange them via drag and drop, as long as a suitable " \
 							"<em>sorting number</em> can be generated.</p><p>If that's not possible, you have " \
-							"to change the number manually via the <strong>Properties dialog box</strong>.</p>").arg(i));
+							"to change the number manually via the <strong>Properties dialog box</strong>.</p>", i));
 
       // create the "STOP" list:
       stopRL[i] = new KSVDragList(stopBox, (_name + " STOP").latin1());
@@ -307,7 +309,7 @@ void KSVContent::initLList()
 		   this, SLOT(fwdUndoAction(KSVAction*)));
 
   // add text-diplay widget
-  textDisplay = new QTextEdit( QString::null, QString::null, this, "TextDisplayWidget" );
+  textDisplay = new Q3TextEdit( QString::null, QString(), this, "TextDisplayWidget" );	//krazy:exclude=nullstrassign for old broken gcc
   textDisplay->setTextFormat( Qt::RichText );
   textDisplay->setReadOnly( true );
 
@@ -322,20 +324,20 @@ void KSVContent::initLList()
 			   this, SLOT(fwdUndoAction(KSVAction*)));
 
 	  // doubleclick && return
-	  connect (startRL[i], SIGNAL(executed(QListViewItem*)),
-			   this, SLOT(slotDoubleClick(QListViewItem*)));
-	  connect (stopRL[i], SIGNAL(executed(QListViewItem*)),
-			   this, SLOT(slotDoubleClick(QListViewItem*)));
-	  connect (startRL[i], SIGNAL(returnPressed(QListViewItem*)),
-			   this, SLOT(slotDoubleClick(QListViewItem*)));
-	  connect (stopRL[i], SIGNAL(returnPressed(QListViewItem*)),
-			   this, SLOT(slotDoubleClick(QListViewItem*)));
+	  connect (startRL[i], SIGNAL(executed(Q3ListViewItem*)),
+			   this, SLOT(slotDoubleClick(Q3ListViewItem*)));
+	  connect (stopRL[i], SIGNAL(executed(Q3ListViewItem*)),
+			   this, SLOT(slotDoubleClick(Q3ListViewItem*)));
+	  connect (startRL[i], SIGNAL(returnPressed(Q3ListViewItem*)),
+			   this, SLOT(slotDoubleClick(Q3ListViewItem*)));
+	  connect (stopRL[i], SIGNAL(returnPressed(Q3ListViewItem*)),
+			   this, SLOT(slotDoubleClick(Q3ListViewItem*)));
 
 	  // context menus
-	  connect (startRL[i], SIGNAL (contextMenu (KListView*, QListViewItem*, const QPoint&)),
-			   this, SLOT (popupRunlevelMenu (KListView*, QListViewItem*, const QPoint&)));
-	  connect (stopRL[i], SIGNAL (contextMenu (KListView*, QListViewItem*, const QPoint&)),
-			   this, SLOT (popupRunlevelMenu (KListView*, QListViewItem*, const QPoint&)));
+	  connect (startRL[i], SIGNAL (contextMenu (K3ListView*, Q3ListViewItem*, const QPoint&)),
+			   this, SLOT (popupRunlevelMenu (K3ListView*, Q3ListViewItem*, const QPoint&)));
+	  connect (stopRL[i], SIGNAL (contextMenu (K3ListView*, Q3ListViewItem*, const QPoint&)),
+			   this, SLOT (popupRunlevelMenu (K3ListView*, Q3ListViewItem*, const QPoint&)));
 
 	  // cannot generate sorting number
 	  connect (startRL[i], SIGNAL(cannotGenerateNumber()),
@@ -351,9 +353,9 @@ void KSVContent::initLList()
 
 	  // use this loop for setting tooltips
  	  startRL[i]->setToolTip (i18n("Drag here to start services\n" \
-                                   "when entering runlevel %1").arg(i));
+                                   "when entering runlevel %1", i));
  	  stopRL[i]->setToolTip (i18n("Drag here to stop services\n" \
-                                  "when entering runlevel %1").arg(i));
+                                  "when entering runlevel %1", i));
 
 	  for (int j = 0; j < ksv::runlevelNumber; ++j)
 		{
@@ -399,7 +401,7 @@ void KSVContent::initScripts() {
     {
       name = fi->fileName();
       scripts->initItem(name,
-                        ksv::IO::relToAbs(conf->scriptPath(), fi->dirPath(FALSE)),
+                        ksv::IO::relToAbs(conf->scriptPath(), fi->path()),
                         name, 0);
 
       comp->addItem (name);
@@ -456,7 +458,7 @@ void KSVContent::info2Widget( QFileInfo* info, int index )
   QFileInfo link_info = QFileInfo(info->readLink());
   QString l_base = link_info.fileName();
 
-  QString l_path = ksv::IO::relToAbs(conf->scriptPath(), link_info.dirPath(FALSE));
+  QString l_path = ksv::IO::relToAbs(conf->scriptPath(), link_info.path());
 
   QString name;
   int number;
@@ -476,14 +478,14 @@ void KSVContent::slotWriteSysV()
 
   for (int i = 0; i < ksv::runlevelNumber; ++i)
     {
-	  appendLog(i18n("<rl>RUNLEVEL %1</rl>").arg(i),
-				i18n("** RUNLEVEL %1 **").arg(i));
+	  appendLog(i18n("<rl>RUNLEVEL %1</rl>", i),
+				i18n("** RUNLEVEL %1 **", i));
 
       clearRL(i); // rm changed/deleted entries
 
       // process "Start"
 	  KSVItem* item = 0L;
-	  for (QListViewItemIterator it (startRL[i]);
+	  for (Q3ListViewItemIterator it (startRL[i]);
 		   (item = static_cast<KSVItem*> (it.current()));
 		   ++it)
 		{
@@ -492,7 +494,7 @@ void KSVContent::slotWriteSysV()
 		}
 
 	  // process "Stop"
-	  for (QListViewItemIterator it (stopRL[i]);
+	  for (Q3ListViewItemIterator it (stopRL[i]);
 		   (item = static_cast<KSVItem*> (it.current()));
 		   ++it)
 		{
@@ -531,7 +533,7 @@ void KSVContent::clearRL(int _rl)
 
   KSVData* d = 0L;
 
-  for (QPtrListIterator<KSVData> it (startRL[_rl]->getDeletedItems());
+  for (Q3PtrListIterator<KSVData> it (startRL[_rl]->getDeletedItems());
 	   (d = it.current());
 	   ++it)
 	{
@@ -549,7 +551,7 @@ void KSVContent::clearRL(int _rl)
   // keep GUI alive
   qApp->processEvents();
 
-  for (QPtrListIterator<KSVData> it (stopRL[_rl]->getDeletedItems());
+  for (Q3PtrListIterator<KSVData> it (stopRL[_rl]->getDeletedItems());
 	   (d = it.current());
 	   ++it)
 	{
@@ -603,20 +605,20 @@ void KSVContent::stopService ()
 
 void KSVContent::stopService (const QString& path)
 {
-  KProcess *_proc = new KProcess();
+  K3Process *_proc = new K3Process();
   _proc->clearArguments();
 
   *_proc << path << "stop";
 
-  connect(_proc, SIGNAL(processExited(KProcess*)), this, SLOT(slotExitedProcess(KProcess*)));
-  connect(_proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
-  connect(_proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
+  connect(_proc, SIGNAL(processExited(K3Process*)), this, SLOT(slotExitedProcess(K3Process*)));
+  connect(_proc, SIGNAL(receivedStdout(K3Process*, char*, int)), this, SLOT(slotOutputOrError(K3Process*, char*, int)));
+  connect(_proc, SIGNAL(receivedStderr(K3Process*, char*, int)), this, SLOT(slotOutputOrError(K3Process*, char*, int)));
 
   // refresh textDisplay
-  appendLog(i18n("** <stop>Stopping</stop> <cmd>%1</cmd> **<br/>").arg(path),
-			i18n("** Stopping %1 **").arg(path));
+  appendLog(i18n("** <stop>Stopping</stop> <cmd>%1</cmd> **<br/>", path),
+			i18n("** Stopping %1 **", path));
 
-  _proc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
+  _proc->start(K3Process::NotifyOnExit, K3Process::AllOutput);
 
   // notify parent
   emit sigRun(path + i18n(" stop"));
@@ -629,20 +631,20 @@ void KSVContent::startService ()
 
 void KSVContent::startService (const QString& path)
 {
-  KProcess* _proc = new KProcess();
+  K3Process* _proc = new K3Process();
   _proc->clearArguments();
 
   *_proc << path << "start";
 
-  connect(_proc, SIGNAL(processExited(KProcess*)), this, SLOT(slotExitedProcess(KProcess*)));
-  connect(_proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
-  connect(_proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
+  connect(_proc, SIGNAL(processExited(K3Process*)), this, SLOT(slotExitedProcess(K3Process*)));
+  connect(_proc, SIGNAL(receivedStdout(K3Process*, char*, int)), this, SLOT(slotOutputOrError(K3Process*, char*, int)));
+  connect(_proc, SIGNAL(receivedStderr(K3Process*, char*, int)), this, SLOT(slotOutputOrError(K3Process*, char*, int)));
 
   // refresh textDisplay
-  appendLog(i18n("** <start>Starting</start> <cmd>%1</cmd> **<br/>").arg(path),
-			i18n("** Starting %1 **").arg(path));
+  appendLog(i18n("** <start>Starting</start> <cmd>%1</cmd> **<br/>", path),
+			i18n("** Starting %1 **", path));
 
-  _proc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
+  _proc->start(K3Process::NotifyOnExit, K3Process::AllOutput);
 
   // notify parent
   emit sigRun(path + i18n(" start"));
@@ -657,7 +659,7 @@ void KSVContent::editService (const QString& path)
 {
   // unfortunately KRun::run() only takes an URL-list instead of a single
   // URL as an argument.
-  KURL url; url.setPath (path); KURL::List urls; urls << url;
+  KUrl url; url.setPath (path); KUrl::List urls; urls << url;
   KRun::run (*ksv::IO::preferredServiceForFile (path), urls);
 }
 
@@ -669,33 +671,33 @@ void KSVContent::restartService ()
 void KSVContent::restartService (const QString& path)
 {
   // restarting
-  KProcess *_proc = new KProcess();
+  K3Process *_proc = new K3Process();
   _proc->clearArguments();
 
   *_proc << path << "restart";
 
-  connect(_proc, SIGNAL(processExited(KProcess*)), this, SLOT(slotExitDuringRestart(KProcess*)));
-  connect(_proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
-  connect(_proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
+  connect(_proc, SIGNAL(processExited(K3Process*)), this, SLOT(slotExitDuringRestart(K3Process*)));
+  connect(_proc, SIGNAL(receivedStdout(K3Process*, char*, int)), this, SLOT(slotOutputOrError(K3Process*, char*, int)));
+  connect(_proc, SIGNAL(receivedStderr(K3Process*, char*, int)), this, SLOT(slotOutputOrError(K3Process*, char*, int)));
 
   // refresh textDisplay
-  appendLog(i18n("** Re-starting <cmd>%1</cmd> **</br>").arg(path),
-			i18n("** Re-starting %1 **").arg(path));
+  appendLog(i18n("** Re-starting <cmd>%1</cmd> **</br>", path),
+			i18n("** Re-starting %1 **", path));
 
-  _proc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
+  _proc->start(K3Process::NotifyOnExit, K3Process::AllOutput);
 
   // notify parent
   emit sigRun(path + i18n(" restart"));
 }
 
-void KSVContent::slotOutputOrError( KProcess*, char* _buffer, int _buflen) {
+void KSVContent::slotOutputOrError( K3Process*, char* _buffer, int _buflen) {
   if (_buflen > 0) {
-    m_buffer += QCString( _buffer, _buflen + 1 );
+    m_buffer += Q3CString( _buffer, _buflen + 1 );
     appendLog( m_buffer );
   }
 }
 
-void KSVContent::slotExitedProcess( KProcess* proc ) {
+void KSVContent::slotExitedProcess( K3Process* proc ) {
   appendLog("<hr/>", "--------------");
 
   emit sigStop();
@@ -707,11 +709,11 @@ void KSVContent::slotScriptsNotRemovable()
   emit sigNotRemovable();
 }
 
-void KSVContent::slotDoubleClick (QListViewItem* item) {
+void KSVContent::slotDoubleClick (Q3ListViewItem* item) {
   infoOnData(static_cast<KSVItem*>(item));
 }
 
-void KSVContent::slotScriptProperties(QListViewItem* item)
+void KSVContent::slotScriptProperties(Q3ListViewItem* item)
 {
   KSVServicePropertiesDialog* prop =
     new KSVServicePropertiesDialog (*static_cast<KSVItem*> (item)->data(), kapp->mainWidget());
@@ -727,21 +729,22 @@ void KSVContent::slotScriptProperties(QListViewItem* item)
 
   prop->exec();
 
+  // the properties dialog autodeletes itself
   //  delete prop;
 }
 
-void KSVContent::slotExitDuringRestart( KProcess* proc )
+void KSVContent::slotExitDuringRestart( K3Process* proc )
 {
   delete proc;
-  proc = new KProcess(); // necessary because otherwise we still have some
+  proc = new K3Process(); // necessary because otherwise we still have some
                          // signals connected that screw up our output
   proc->clearArguments();
 
-  connect(proc, SIGNAL(processExited(KProcess*)), this, SLOT(slotExitedProcess(KProcess*)));
-  connect(proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
-  connect(proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
+  connect(proc, SIGNAL(processExited(K3Process*)), this, SLOT(slotExitedProcess(K3Process*)));
+  connect(proc, SIGNAL(receivedStdout(K3Process*, char*, int)), this, SLOT(slotOutputOrError(K3Process*, char*, int)));
+  connect(proc, SIGNAL(receivedStderr(K3Process*, char*, int)), this, SLOT(slotOutputOrError(K3Process*, char*, int)));
 
-  proc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
+  proc->start(K3Process::NotifyOnExit, K3Process::AllOutput);
 }
 
 KSVDragList* KSVContent::getOrigin()
@@ -765,7 +768,7 @@ void KSVContent::setDisplayScriptOutput(bool val)
   calcMinSize();
 }
 
-int KSVContent::splitterToPanningFactor (const QValueList<int>& list)
+int KSVContent::splitterToPanningFactor (const Q3ValueList<int>& list)
 {
   const int cont_size = *list.at(0);
   const int log_size = *list.at(1);
@@ -773,9 +776,9 @@ int KSVContent::splitterToPanningFactor (const QValueList<int>& list)
   return cont_size * 100 / (cont_size + log_size);
 }
 
-const QValueList<int>& KSVContent::panningFactorToSplitter (int panningFactor)
+const Q3ValueList<int>& KSVContent::panningFactorToSplitter (int panningFactor)
 {
-  static QValueList<int> res;
+  static Q3ValueList<int> res;
   res.clear();
 
   res << panningFactor << 100 - panningFactor;
@@ -798,13 +801,13 @@ void KSVContent::appendLog (const QString& rich, const QString& plain)
   textDisplay->append (rich);
 }
 
-void KSVContent::appendLog(const QCString& _buffer)
+void KSVContent::appendLog(const Q3CString& _buffer)
 {
     QStringList _lines = QStringList::split( "\n", QString::fromLocal8Bit( _buffer ) );
     for ( QStringList::Iterator it = _lines.begin(); it != _lines.end(); ++it )
         appendLog( *it, *it );
 
-    m_buffer = QCString();
+    m_buffer = Q3CString();
 }
 
 const QString& KSVContent::log () const
@@ -856,7 +859,7 @@ void KSVContent::pasteAppend()
     {
 	  KSVData data;
 
-	  if (KSVDrag::decodeNative (kapp->clipboard()->data(), data))
+	  if (KSVDrag::decodeNative (QApplication::clipboard()->data(), data))
 		{
 		  KSVAction* action = 0L;
 
@@ -903,7 +906,7 @@ void KSVContent::setColors (const QColor& newNormal,
 
 void KSVContent::multiplexEnabled (bool val)
 {
-  QListView* list = getOrigin();
+  Q3ListView* list = getOrigin();
 
 
   if (list)
@@ -946,11 +949,11 @@ void KSVContent::multiplexEnabled (bool val)
 		 "next time %3 is run. If you choose not to "      \
 		 "reconfigure, you will not be able to view or "   \
 		 "edit your system's init configuration.</p>"      \
-		 "<p>Would you like to reconfigure %4?</p>")
-	   .arg (config->scriptPath())
-	   .arg (kapp->aboutData()->programName())
-	   .arg (kapp->aboutData()->programName())
-	   .arg (kapp->aboutData()->programName()),
+		 "<p>Would you like to reconfigure %4?</p>",
+	     config->scriptPath(),
+	     KGlobal::mainComponent().aboutData()->programName(),
+	     KGlobal::mainComponent().aboutData()->programName(),
+	     KGlobal::mainComponent().aboutData()->programName()),
 	   i18n("Folder Does Not Exist"),i18n("Reconfigure"),i18n("Do Not Reconfigure"));
 
 	if ( choice == KMessageBox::Yes )
@@ -971,9 +974,9 @@ void KSVContent::multiplexEnabled (bool val)
 					"user), or ask your sysadmin to install %2 "         \
 					"<em>suid</em> or <em>sgid</em>.</p>"                \
 					"<p>The latter way is not recommended though, "      \
-					"due to security issues.</p>")
-				  .arg (kapp->aboutData()->programName())
-				  .arg (kapp->aboutData()->programName()),
+					"due to security issues.</p>",
+				    KGlobal::mainComponent().aboutData()->programName(),
+				    KGlobal::mainComponent().aboutData()->programName()),
 				  i18n("Insufficient Permissions"),
 				  ksv::notifications[ksv::RunlevelsReadOnly]);
       }
@@ -994,7 +997,7 @@ void KSVContent::showRunlevel (int index)
   calcMinSize();
 }
 
-void KSVContent::popupRunlevelMenu (KListView* list, QListViewItem* i, const QPoint& p)
+void KSVContent::popupRunlevelMenu (K3ListView* list, Q3ListViewItem* i, const QPoint& p)
 {
   if (i)
 	mItemMenu->exec (p, 1);
@@ -1005,7 +1008,7 @@ void KSVContent::popupRunlevelMenu (KListView* list, QListViewItem* i, const QPo
 	}
 }
 
-void KSVContent::popupServicesMenu (KListView*, QListViewItem* i, const QPoint& p)
+void KSVContent::popupServicesMenu (K3ListView*, Q3ListViewItem* i, const QPoint& p)
 {
   if (i)
     {
@@ -1034,12 +1037,12 @@ void KSVContent::popupServicesMenu (KListView*, QListViewItem* i, const QPoint&
 
 void KSVContent::openWith ()
 {
-  KURL url; url.setPath(static_cast<KSVItem*>(getOrigin()->currentItem())->filenameAndPath());
-  KURL::List urls; urls.append (url);
+  KUrl url; url.setPath(static_cast<KSVItem*>(getOrigin()->currentItem())->filenameAndPath());
+  KUrl::List urls; urls.append (url);
 
 	KRun::displayOpenWithDialog (urls);
 
-  kdDebug(3000) << "Opening with..." << endl;
+  kDebug(3000) << "Opening with...";
 }
 
 void KSVContent::openWith (int index)
@@ -1048,12 +1051,12 @@ void KSVContent::openWith (int index)
     return;
 
   KService::Ptr service = *mOpenWithOffers.at (index);
-  KURL url; url.setPath(static_cast<KSVItem*>(getOrigin()->currentItem())->filenameAndPath());
-  KURL::List urls; urls.append (url);
+  KUrl url; url.setPath(static_cast<KSVItem*>(getOrigin()->currentItem())->filenameAndPath());
+  KUrl::List urls; urls.append (url);
 
   KRun::run (*service, urls);
 
-  kdDebug(3000) << "Opening with " << service->exec() << endl;
+  kDebug(3000) << "Opening with " << service->exec();
 }
 
 void KSVContent::calcMinSize ()
@@ -1071,7 +1074,7 @@ void KSVContent::calcMinSize ()
         continue;
 
       w += KDialog::spacingHint() + mRunlevels[i]->sizeHint().width();
-      h = kMax (h, mRunlevels[i]->sizeHint().height());
+      h = QMax (h, mRunlevels[i]->sizeHint().height());
     }
 
   mContent->layout()->setEnabled(false);
@@ -1080,8 +1083,8 @@ void KSVContent::calcMinSize ()
   mContent->layout()->setEnabled(true);
 }
 
-void KSVContent::mergeLoadedPackage (QValueList<KSVData>* start,
-                                     QValueList<KSVData>* stop)
+void KSVContent::mergeLoadedPackage (Q3ValueList<KSVData>* start,
+                                     Q3ValueList<KSVData>* stop)
 {
   for (int i = 0; i < ksv::runlevelNumber; ++i)
     {
@@ -1090,12 +1093,12 @@ void KSVContent::mergeLoadedPackage (QValueList<KSVData>* start,
     }
 }
 
-void KSVContent::merge (QValueList<KSVData>& list, KSVDragList* widget)
+void KSVContent::merge (Q3ValueList<KSVData>& list, KSVDragList* widget)
 {
   typedef QMap<KSVData, bool> LoadMap;
   LoadMap loaded;
 
-  for (QValueListIterator<KSVData> it = list.begin();
+  for (Q3ValueListIterator<KSVData> it = list.begin();
        it != list.end();
        ++it)
     {
@@ -1123,13 +1126,13 @@ void KSVContent::merge (QValueList<KSVData>& list, KSVDragList* widget)
           emit undoAction (new AddAction (widget, item->data()));
         }
 
-      kapp->processEvents ();
+      qApp->processEvents ();
     }
 
-  QPtrList<KSVItem> deleteList;
+  Q3PtrList<KSVItem> deleteList;
   deleteList.setAutoDelete (true);
 
-  for (QListViewItemIterator it (widget); it.current(); ++it)
+  for (Q3ListViewItemIterator it (widget); it.current(); ++it)
     {
       KSVItem* item = static_cast<KSVItem*> (it.current());
 
@@ -1140,11 +1143,11 @@ void KSVContent::merge (QValueList<KSVData>& list, KSVDragList* widget)
           emit undoAction (new RemoveAction (widget, item->data()));
         }
 
-      kapp->processEvents ();
+      qApp->processEvents ();
     }
 
   widget->sort();
-  kapp->processEvents();
+  qApp->processEvents();
 }
 
 #include "OldView.moc"
