@@ -1,5 +1,4 @@
-/* ksvpathconfig.h
-**
+/*
 ** Copyright (C) 2000 Peter Putzer <putzer@kde.org>
 **
 */
@@ -17,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -33,7 +32,7 @@ class KSVPathConfig : public PathConfiguration
   Q_OBJECT
   
 public:
-  KSVPathConfig( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
+  KSVPathConfig( QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = 0 );
   ~KSVPathConfig();
 
 signals:
